# TODOs

- allow multiple precursors in one ms1 spec with different elution profiles
- implement proper fragmentation functions for peptides and nucleosides
- add intensity scaling parameter for different molecules
- 
